abacusai.twitter_search_result — AbacusAI documentation

# abacusai.twitter_search_result

## Classes

`TwitterSearchResult` | A single twitter search result.

## Module Contents

class abacusai.twitter_search_result.TwitterSearchResult(client, title=None, url=None, twitterName=None, twitterHandle=None, thumbnailUrl=None, thumbnailWidth=None, thumbnailHeight=None)

  Bases: `abacusai.return_class.AbstractApiClass`

  A single twitter search result.

  Parameters:

    - client (ApiClient) – An authenticated API Client instance

    - title (str) – The title of the tweet.

    - url (str) – The URL of the tweet.

    - twitterName (str) – The name of the twitter user.

    - twitterHandle (str) – The handle of the twitter user.

    - thumbnailUrl (str) – The URL of the thumbnail of the tweet.

    - thumbnailWidth (int) – The width of the thumbnail of the tweet.

    - thumbnailHeight (int) – The height of the thumbnail of the tweet.

  title
  url
  twitter_name
  twitter_handle
  thumbnail_url
  thumbnail_width
  thumbnail_height
  deprecated_keys
  __repr__()
  to_dict()

    Get a dict representation of the parameters in this class

    Returns:

      The dict value representation of the class parameters

    Return type:

      dict